@@ -108,7 +108,7 @@ extern void ExtGetZAxis();
 
 extern void ExtDumpCaps();
 
-extern int extEnumTilePerim(Tile *tpIn, const TileTypeBitMask *maskp, int pNum, int (*func)(), ClientData cdata);
+extern int extEnumTilePerim(Tile *tpIn, TileType dinfo, const TileTypeBitMask *maskp, int pNum, int (*func)(), ClientData cdata);
 extern Plane *extPrepSubstrate();
 
 /* C99 compat */
