@@ -351,8 +351,9 @@ ResMakeLabelBreakpoints(def, goodies)
  */
 
 int
-ResAddBreakpointFunc(tile, node)
+ResAddBreakpointFunc(tile, dinfo, node)
    Tile *tile;
+   TileType dinfo;		/* (unused) */
    ResSimNode *node;
 {
     tileJunk *junk;
@@ -741,8 +742,9 @@ ResCalcPerimOverlap(tile, dev)
  */
 
 int
-resMakeDevFunc(tile, cx)
+resMakeDevFunc(tile, dinfo, cx)
     Tile	*tile;
+    TileType	dinfo;
     TreeContext *cx;
 {
     ResDevTile	*thisDev = (ResDevTile *)cx->tc_filter->tf_arg;
@@ -753,7 +755,7 @@ resMakeDevFunc(tile, cx)
     GeoTransRect(&cx->tc_scx->scx_trans, &devArea, &thisDev->area);
 
     if (IsSplit(tile))
-	ttype = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
+	ttype = ((dinfo & TT_SIDE)) ? SplitRightType(tile) : SplitLeftType(tile);
     else
 	ttype = TiGetType(tile);
 
@@ -795,8 +797,9 @@ resMakeDevFunc(tile, cx)
 #define DEV_PROCESSED 1
 
 int
-resExpandDevFunc(tile, cx)
+resExpandDevFunc(tile, dinfo, cx)
     Tile	*tile;
+    TileType	dinfo;		/* Split tile information (unused) */
     TreeContext *cx;
 {
     ResDevTile	    *thisDev = (ResDevTile *)cx->tc_filter->tf_arg;
@@ -918,8 +921,9 @@ resExpandDevFunc(tile, cx)
  */
 
 int
-ResShaveContacts(tile, def)
+ResShaveContacts(tile, dinfo, def)
     Tile *tile;
+    TileType dinfo;	/* (unused, see comment below) */
     CellDef *def;
 {
     TileType ttype;
@@ -1117,7 +1121,7 @@ ResExtractNet(node, goodies, cellname)
     }
     DBReComputeBbox(ResUse->cu_def);
 
-    ExtResetTiles(scx.scx_use->cu_def, extUnInit);
+    ExtResetTiles(scx.scx_use->cu_def, CLIENTDEFAULT);
 
     /* To avoid issues with overlapping stacked contact types and	*/
     /* double-counting contacts on multiple planes, erase the top	*/
@@ -1144,9 +1148,8 @@ ResExtractNet(node, goodies, cellname)
     ResContactList = (ResContactPoint *)ExtFindRegions(ResUse->cu_def,
 				     &(ResUse->cu_def->cd_bbox),
 				     &DBAllButSpaceAndDRCBits,
-				     ResConnectWithSD, extUnInit, ResFirst,
-				     ResEach);
-    ExtResetTiles(ResUse->cu_def, extUnInit);
+				     ResConnectWithSD, ResFirst, ResEach);
+    ExtResetTiles(ResUse->cu_def, CLIENTDEFAULT);
 
     /*
      * dissolve the contacts and find which tiles now cover the point
@@ -1287,8 +1290,10 @@ ResCleanUpEverything()
  */
 
 int
-ResGetTileFunc(tile, tpptr)
-    Tile *tile, **tpptr;
+ResGetTileFunc(tile, dinfo, tpptr)
+    Tile *tile;
+    TileType dinfo;		/* (unused) */
+    Tile **tpptr;
 {
     if (TiGetType(tile) != TT_SPACE)
     {
